Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::view::stride_fn Member List

This is the complete list of members for ranges::v3::view::stride_fn, including all inherited members.

operator()(Rng &&rng, range_difference_type_t< Rng > step) const noexcept(noexcept(decltype(stride_view< all_t< Rng >>{all(static_cast< Rng &&>(rng)), step})(stride_view< all_t< Rng >>{all(static_cast< Rng &&>(rng)), step}))) -> decltype(stride_view< all_t< Rng >> (defined in ranges::v3::view::stride_fn) | ranges::v3::view::stride_fn |
stride (defined in ranges::v3::view::stride_fn) | ranges::v3::view::stride_fn | related